@@ -3,7 +3,7 @@
 # -----------------------------------------------------------------
 # This file is a part of PAMPI project.
 # Name:         PAMPI
-# Copyright:    (C) 2017-2021 Pascal PETER
+# Copyright:    (C) 2017-2024 Pascal PETER
 #               contributions in 2021 by G. Khaznadar
 # Licence:      GNU General Public Licence version 3
 # Website:      http://pascal.peter.free.fr/
@@ -31,7 +31,6 @@ DESCRIPTION :
 """
 
 # importation des modules utiles :
-from __future__ import division, print_function
 
 # importation des modules perso :
 import utils
@@ -46,11 +45,7 @@ from utils_editor import markdownEditor
 
 import os, re, importlib
 
-# PyQt5 ou PyQt4 :
-if utils.PYQT == 'PYQT5':
-    from PyQt5 import QtCore, QtWidgets, QtGui
-else:
-    from PyQt4 import QtCore, QtGui as QtWidgets, QtGui
+from PyQt5 import QtCore, QtWidgets, QtGui
 
 
 class MainWindow(QtWidgets.QMainWindow, Ui_MainWindow):
@@ -128,7 +123,7 @@ class MainWindow(QtWidgets.QMainWindow, Ui_MainWindow):
         self.updateWindowTitle()
         self.updateLastFilesMenu()
         rect = QtWidgets.QApplication.desktop().availableGeometry()
-        self.resize(3 * rect.width() / 4, 3 * rect.height() / 4)
+        self.resize(3 * rect.width() // 4, 3 * rect.height() // 4)
         self.showHelp(here=True)
         self.markdownEditor.setFocus()
         self.loadPlugins()
@@ -179,13 +174,13 @@ class MainWindow(QtWidgets.QMainWindow, Ui_MainWindow):
         lines = utils_filesdirs.readTextFile(self.examplesFile)        
         self.samplesEditor.setPlainText(lines)
         rect = QtWidgets.QApplication.desktop().availableGeometry()
-        self.hsplitter.setSizes([rect.width() / 3, rect.width() / 2])
+        self.hsplitter.setSizes([rect.width() // 3, rect.width() // 2])
         self.closing = False
         self.createActions()
         self.createMenusAndButtons()
 
         # Barre d'outils en haut, pour les plugins
-        self.pluginsWidget.setMinimumHeight(1.5 * utils.STYLE['PM_ToolBarIconSize'])
+        self.pluginsWidget.setMinimumHeight(int(1.5 * utils.STYLE['PM_ToolBarIconSize']))
         #self.pluginToolBar = QtWidgets.QToolBar(self)
         self.pluginToolBar = QtWidgets.QToolBar(self.pluginsWidget)
         self.pluginToolBar.setIconSize(iconsize)
@@ -755,7 +750,7 @@ class MainWindow(QtWidgets.QMainWindow, Ui_MainWindow):
         pandocBin = ''
         if utils.OS_NAME[0] == 'win':
             pandocBin = utils_functions.u(
-                '{0}\libs\win\pandoc.exe').format(
+                r'{0}\libs\win\pandoc.exe').format(
                     QtCore.QDir.toNativeSeparators(self.beginDir))
         else:
             possiblePaths = ('/usr/local/bin', '/opt', '/usr/bin', )
@@ -848,7 +843,7 @@ class MainWindow(QtWidgets.QMainWindow, Ui_MainWindow):
                 args = [
                     '--template', 
                     utils_functions.u(
-                        '{0}\_template.html').format(
+                        r'{0}\_template.html').format(
                             QtCore.QDir.toNativeSeparators(self.tempPath))]
             else:
                 args = ['--template', templateFileName]
@@ -868,11 +863,11 @@ class MainWindow(QtWidgets.QMainWindow, Ui_MainWindow):
                 '-s', '-t', 'html5', '--section-divs', '-o'])
             if utils.OS_NAME[0] == 'win':
                 args.append(
-                    utils_functions.u('{0}\{1}.html').format(
+                    utils_functions.u(r'{0}\{1}.html').format(
                         QtCore.QDir.toNativeSeparators(self.presentationsDir), 
                         outFileName))
                 args.append(
-                    utils_functions.u('{0}\md\{1}.md').format(
+                    utils_functions.u(r'{0}\md\{1}.md').format(
                         QtCore.QDir.toNativeSeparators(self.presentationsDir), 
                         self.actualFile['baseName']))
             else:
