@@ -4,10 +4,7 @@ Un plugin destiné à Pampi, pour insérer une animation dans l'éditeur
 "rotation-X"
 """
 
-try:
-    from PyQt5 import QtCore, QtWidgets, QtGui
-except:
-    from PyQt4 import QtCore, QtGui as QtWidgets, QtGui
+from PyQt5 import QtCore
 
 
 from ._anim_template import Plugin as AnimPlugin, AnimDialog
